#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_ecmwf.main import Main


class satellite_land_cover(Main):
    name = "EO:ECMWF:DAT:SATELLITE_LAND_COVER"
    dataset = "EO:ECMWF:DAT:SATELLITE_LAND_COVER"

    choices = [
        "variable",
        "format_",
    ]

    string_selects = [
        "version",
        "year",
    ]

    @normalize(
        "version",
        [
            "v2.0.7cds",
            "v2.1.1",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "1992",
            "1993",
            "1994",
            "1995",
            "1996",
            "1997",
            "1998",
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
        ],
        multiple=True,
    )
    @normalize(
        "format_",
        [
            "tgz",
            "zip",
        ],
    )
    @normalize(
        "variable",
        [
            "all",
        ],
    )
    def __init__(
        self,
        version,
        year,
        format_,
        variable="all",
    ):
        super().__init__(
            version=version,
            year=year,
            format_=format_,
            variable=variable,
        )
