#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_ecmwf.main import Main


class seasonal_original_pressure_levels(Main):
    name = "EO:ECMWF:DAT:SEASONAL_ORIGINAL_PRESSURE_LEVELS"
    dataset = "EO:ECMWF:DAT:SEASONAL_ORIGINAL_PRESSURE_LEVELS"

    choices = [
        "originating_centre",
        "system",
        "format_",
    ]

    string_selects = [
        "day",
        "leadtime_hour",
        "month",
        "pressure_level",
        "variable",
        "year",
    ]

    @normalize(
        "day",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "20",
            "21",
            "22",
            "23",
            "24",
            "25",
            "26",
            "27",
            "28",
            "29",
            "30",
            "31",
        ],
        multiple=True,
    )
    @normalize(
        "leadtime_hour",
        [
            "1008",
            "1020",
            "1032",
            "1044",
            "1056",
            "1068",
            "108",
            "1080",
            "1092",
            "1104",
            "1116",
            "1128",
            "1140",
            "1152",
            "1164",
            "1176",
            "1188",
            "12",
            "120",
            "1200",
            "1212",
            "1224",
            "1236",
            "1248",
            "1260",
            "1272",
            "1284",
            "1296",
            "1308",
            "132",
            "1320",
            "1332",
            "1344",
            "1356",
            "1368",
            "1380",
            "1392",
            "1404",
            "1416",
            "1428",
            "144",
            "1440",
            "1452",
            "1464",
            "1476",
            "1488",
            "1500",
            "1512",
            "1524",
            "1536",
            "1548",
            "156",
            "1560",
            "1572",
            "1584",
            "1596",
            "1608",
            "1620",
            "1632",
            "1644",
            "1656",
            "1668",
            "168",
            "1680",
            "1692",
            "1704",
            "1716",
            "1728",
            "1740",
            "1752",
            "1764",
            "1776",
            "1788",
            "180",
            "1800",
            "1812",
            "1824",
            "1836",
            "1848",
            "1860",
            "1872",
            "1884",
            "1896",
            "1908",
            "192",
            "1920",
            "1932",
            "1944",
            "1956",
            "1968",
            "1980",
            "1992",
            "2004",
            "2016",
            "2028",
            "204",
            "2040",
            "2052",
            "2064",
            "2076",
            "2088",
            "2100",
            "2112",
            "2124",
            "2136",
            "2148",
            "216",
            "2160",
            "2172",
            "2184",
            "2196",
            "2208",
            "2220",
            "2232",
            "2244",
            "2256",
            "2268",
            "228",
            "2280",
            "2292",
            "2304",
            "2316",
            "2328",
            "2340",
            "2352",
            "2364",
            "2376",
            "2388",
            "24",
            "240",
            "2400",
            "2412",
            "2424",
            "2436",
            "2448",
            "2460",
            "2472",
            "2484",
            "2496",
            "2508",
            "252",
            "2520",
            "2532",
            "2544",
            "2556",
            "2568",
            "2580",
            "2592",
            "2604",
            "2616",
            "2628",
            "264",
            "2640",
            "2652",
            "2664",
            "2676",
            "2688",
            "2700",
            "2712",
            "2724",
            "2736",
            "2748",
            "276",
            "2760",
            "2772",
            "2784",
            "2796",
            "2808",
            "2820",
            "2832",
            "2844",
            "2856",
            "2868",
            "288",
            "2880",
            "2892",
            "2904",
            "2916",
            "2928",
            "2940",
            "2952",
            "2964",
            "2976",
            "2988",
            "300",
            "3000",
            "3012",
            "3024",
            "3036",
            "3048",
            "3060",
            "3072",
            "3084",
            "3096",
            "3108",
            "312",
            "3120",
            "3132",
            "3144",
            "3156",
            "3168",
            "3180",
            "3192",
            "3204",
            "3216",
            "3228",
            "324",
            "3240",
            "3252",
            "3264",
            "3276",
            "3288",
            "3300",
            "3312",
            "3324",
            "3336",
            "3348",
            "336",
            "3360",
            "3372",
            "3384",
            "3396",
            "3408",
            "3420",
            "3432",
            "3444",
            "3456",
            "3468",
            "348",
            "3480",
            "3492",
            "3504",
            "3516",
            "3528",
            "3540",
            "3552",
            "3564",
            "3576",
            "3588",
            "36",
            "360",
            "3600",
            "3612",
            "3624",
            "3636",
            "3648",
            "3660",
            "3672",
            "3684",
            "3696",
            "3708",
            "372",
            "3720",
            "3732",
            "3744",
            "3756",
            "3768",
            "3780",
            "3792",
            "3804",
            "3816",
            "3828",
            "384",
            "3840",
            "3852",
            "3864",
            "3876",
            "3888",
            "3900",
            "3912",
            "3924",
            "3936",
            "3948",
            "396",
            "3960",
            "3972",
            "3984",
            "3996",
            "4008",
            "4020",
            "4032",
            "4044",
            "4056",
            "4068",
            "408",
            "4080",
            "4092",
            "4104",
            "4116",
            "4128",
            "4140",
            "4152",
            "4164",
            "4176",
            "4188",
            "420",
            "4200",
            "4212",
            "4224",
            "4236",
            "4248",
            "4260",
            "4272",
            "4284",
            "4296",
            "4308",
            "432",
            "4320",
            "4332",
            "4344",
            "4356",
            "4368",
            "4380",
            "4392",
            "4404",
            "4416",
            "4428",
            "444",
            "4440",
            "4452",
            "4464",
            "4476",
            "4488",
            "4500",
            "4512",
            "4524",
            "4536",
            "4548",
            "456",
            "4560",
            "4572",
            "4584",
            "4596",
            "4608",
            "4620",
            "4632",
            "4644",
            "4656",
            "4668",
            "468",
            "4680",
            "4692",
            "4704",
            "4716",
            "4728",
            "4740",
            "4752",
            "4764",
            "4776",
            "4788",
            "48",
            "480",
            "4800",
            "4812",
            "4824",
            "4836",
            "4848",
            "4860",
            "4872",
            "4884",
            "4896",
            "4908",
            "492",
            "4920",
            "4932",
            "4944",
            "4956",
            "4968",
            "4980",
            "4992",
            "5004",
            "5016",
            "5028",
            "504",
            "5040",
            "5052",
            "5064",
            "5076",
            "5088",
            "5100",
            "5112",
            "5124",
            "5136",
            "5148",
            "516",
            "5160",
            "528",
            "540",
            "552",
            "564",
            "576",
            "588",
            "60",
            "600",
            "612",
            "624",
            "636",
            "648",
            "660",
            "672",
            "684",
            "696",
            "708",
            "72",
            "720",
            "732",
            "744",
            "756",
            "768",
            "780",
            "792",
            "804",
            "816",
            "828",
            "84",
            "840",
            "852",
            "864",
            "876",
            "888",
            "900",
            "912",
            "924",
            "936",
            "948",
            "96",
            "960",
            "972",
            "984",
            "996",
        ],
        multiple=True,
    )
    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "pressure_level",
        [
            "10",
            "100",
            "1000",
            "200",
            "30",
            "300",
            "400",
            "50",
            "500",
            "700",
            "850",
            "925",
        ],
        multiple=True,
    )
    @normalize(
        "variable",
        [
            "geopotential",
            "specific_humidity",
            "temperature",
            "u_component_of_wind",
            "v_component_of_wind",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "1981",
            "1982",
            "1983",
            "1984",
            "1985",
            "1986",
            "1987",
            "1988",
            "1989",
            "1990",
            "1991",
            "1992",
            "1993",
            "1994",
            "1995",
            "1996",
            "1997",
            "1998",
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
            "2022",
            "2023",
        ],
        multiple=True,
    )
    @normalize(
        "originating_centre",
        [
            "cmcc",
            "dwd",
            "eccc",
            "ecmwf",
            "jma",
            "meteo_france",
            "ncep",
            "ukmo",
        ],
    )
    @normalize(
        "system",
        [
            "1",
            "12",
            "13",
            "14",
            "15",
            "2",
            "21",
            "3",
            "35",
            "4",
            "5",
            "51",
            "6",
            "600",
            "601",
            "602",
            "7",
            "8",
        ],
    )
    @normalize(
        "format_",
        [
            "grib",
            "netcdf",
        ],
    )
    @normalize("area", "bounding-box(list)")
    def __init__(
        self,
        day,
        leadtime_hour,
        month,
        pressure_level,
        variable,
        year,
        originating_centre,
        system,
        format_,
        area=None,
    ):
        super().__init__(
            day=day,
            leadtime_hour=leadtime_hour,
            month=month,
            pressure_level=pressure_level,
            variable=variable,
            year=year,
            originating_centre=originating_centre,
            system=system,
            format_=format_,
            area=area,
        )
